****************
Sample Annotator
****************

.. autoclass:: orangecontrib.bioinformatics.annotation.annotate_samples.AnnotateSamples()
   :members:

********************
Projection Annotator
********************

.. automodule:: orangecontrib.bioinformatics.annotation.annotate_projection
   :members:
